# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.25.0~db7f23b',
    built_at='2025-12-02 08:23:18Z',
    sha='db7f23bc582af31b06a5af41a3420190451f86e9',
    branch='HEAD',
    tag='v4.25.0',
)
